package com.dcs.hnyz.service;

import java.util.List;
import com.dcs.hnyz.domain.DcsGroupTask;

/**
 * 任务动作组Service接口
 *
 * @author wuhb
 * @date 2025-08-04
 */
public interface IDcsGroupTaskService
{
    /**
     * 查询任务动作组
     *
     * @param groupId 任务动作组主键
     * @return 任务动作组
     */
    public DcsGroupTask selectDcsGroupTaskByGroupId(Long groupId);

    /**
     * 查询任务动作组列表
     *
     * @param dcsGroupTask 任务动作组
     * @return 任务动作组集合
     */
    public List<DcsGroupTask> selectDcsGroupTaskList(DcsGroupTask dcsGroupTask);

    /**
     * 新增任务动作组
     *
     * @param dcsGroupTask 任务动作组
     * @return 结果
     */
    public int insertDcsGroupTask(DcsGroupTask dcsGroupTask);

    /**
     * 修改任务动作组
     *
     * @param dcsGroupTask 任务动作组
     * @return 结果
     */
    public int updateDcsGroupTask(DcsGroupTask dcsGroupTask);

    /**
     * 批量删除任务动作组
     *
     * @param groupIds 需要删除的任务动作组主键集合
     * @return 结果
     */
    public int deleteDcsGroupTaskByGroupIds(Long[] groupIds);

    /**
     * 删除任务动作组信息
     *
     * @param groupId 任务动作组主键
     * @return 结果
     */
    public int deleteDcsGroupTaskByGroupId(Long groupId);

    public DcsGroupTask selectDcsGroupTaskByGroupCode(String groupCode);
}
